==> kleopatra-16.04.1.tar.xz: kleopatra-16.04.1/src/conf/gnupgsystemconfigurationpage.h <==
/* -*- mode: c++; c-basic-offset:4 -*-
    conf/gnupgsystemconfigurationpage.h

    This file is part of Kleopatra, the KDE keymanager
    Copyright (c) 2008 Klarälvdalens Datakonsult AB

    Kleopatra is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Kleopatra is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/
#ifndef KLEOPATRA_GNUPGSYSTEMCONFIGURATIONPAGE_H
#define KLEOPATRA_GNUPGSYSTEMCONFIGURATIONPAGE_H

#include <kcmodule.h>
namespace Kleo
{
class CryptoConfigModule;
}

namespace Kleo
{
namespace Config
{

class GnuPGSystemConfigurationPage : public KCModule
{
    Q_OBJECT
public:
    explicit GnuPGSystemConfigurationPage(QWidget *parent = Q_NULLPTR, const QVariantList &args = QVariantList());
    ~GnuPGSystemConfigurationPage();

    void load() Q_DECL_OVERRIDE;
    void save() Q_DECL_OVERRIDE;
    void defaults() Q_DECL_OVERRIDE;

private:
    Kleo::CryptoConfigModule *mWidget;
};

}
}

#endif // KLEOPATRA_GNUPGSYSTEMCONFIGURATIONPAGE_H

==> kleopatra-20.03.90.tar.xz: kleopatra-20.03.90/src/conf/gnupgsystemconfigurationpage.h <==
/* -*- mode: c++; c-basic-offset:4 -*-
    conf/gnupgsystemconfigurationpage.h

    This file is part of Kleopatra, the KDE keymanager
    Copyright (c) 2008 Klarälvdalens Datakonsult AB

    Kleopatra is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Kleopatra is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/
#ifndef KLEOPATRA_GNUPGSYSTEMCONFIGURATIONPAGE_H
#define KLEOPATRA_GNUPGSYSTEMCONFIGURATIONPAGE_H

#include <KCModule>
namespace Kleo
{
class CryptoConfigModule;
}

namespace Kleo
{
namespace Config
{

class GnuPGSystemConfigurationPage : public KCModule
{
    Q_OBJECT
public:
    explicit GnuPGSystemConfigurationPage(QWidget *parent = nullptr, const QVariantList &args = QVariantList());
    ~GnuPGSystemConfigurationPage() override;

    void load() override;
    void save() override;
    void defaults() override;

private:
    Kleo::CryptoConfigModule *mWidget;
};

}
}

#endif // KLEOPATRA_GNUPGSYSTEMCONFIGURATIONPAGE_H
